<?php

class SoftwareCode {
	private $URL = "http://swcode.nl/api/";
	private $WSDL = "http://swcode.nl/api/?WSDL";

	private $username = NULL;
	private $password = NULL;
	private $signature = NULL;
	private $testingmode = false;

	private $soapclient = NULL;
                             
    /*
            Creates the SoapClient and sets some variables used for authentication.
            
            Variables:
                    $username: Username of the service
                    $password: Hash of the password known with us
                    $signature: An unique Hash used for communicating with the API       
                    
            Returns: 
                    Nothing.
    */
	function __construct($username, $password, $signature)
	{
		$this->username = $username;
		$this->signature = $signature;
		$this->password = $password;
	
		$this->soapclient = new SoapClient($this->WSDL, array('cache_wsdl' => WSDL_CACHE_NONE));
		if (!$this->soapclient)
			trigger_error("Failure to establish a communication with the remote server");
	}        
    
    /*
            Sets testing mode to enabled to not work with real products.
              
            Variables:
                   None.         
                   
            Returns;
                   The new state of testingmode.
    */
	public function setTestingModeEnabled()
	{
		$this->testingmode = true;            
	        return $this->testingmode;
	}
          
    /*
               Function used for fetching the products list.
               
               Variables:
                        None.
                        
               Returns: 
                        An array with product details.
						[ productID ] =>
								['productID']: Product ID
								['productName']: Product display name
								['productGroup']: Product group
								['productShortName']: Product short name, usally VendorPartNumber
								['productLicenseNoDevices']: For how many devices?
								['productLicenseTimespan']: License time period
								['enduserPrice']: Enduser sale price
								['inStock']: Boolean, true if in stock
								['isRenewal']: boolean, renewal only, true needs an license code supplied
    */
	public function fetchProductList()
	{
		$requestSignature = sha1( $this->password . $this->username . $this->signature );
		return $this->soapclient->fetchProducts( $this->username, $requestSignature, $this->testingmode );		
	}	          
    
     /*
               Function used for fetching the server time and testing comminucation.
               
               Variables:
                        None.
                        
               Returns: 
                        An UNIX timestamp.
    */
	public function fetchServerTime()
	{
		return $this->soapclient->ping();
	}
    
    /*
               Function used for retrieving licences
               
               Variables:
                        $endUserDetails, array with enduserdetails.
                        $productID: APN of product
						$renewalCode: Optional, old renewal code.	
               Returns: 
                        Returns an array:
							[0] = true if successful.
							["id"] = reference ID of server
							["license"] = Given license key
							["enduser"] = array with parsed enduser details
    */
	public function fetchLicense( $endUserDetails, $productID, $renewalCode )
	{
		if (!isset($endUserDetails['firstname']) || !isset($endUserDetails['lastname']))
			return array( false, 0 );

		$requestSignature = sha1( $this->password . $this->username . $endUserDetails['lastname'] . $this->signature  );
		$endUserDetails =  json_encode($endUserDetails);
		return $this->soapclient->createLicense( $endUserDetails, $this->username, 'r', $productID, $renewalCode, $requestSignature, $this->testingmode );
	}
}
